@@ -24,7 +24,7 @@ sleep $DAEMON_TIMEOUT
 # online
 #
 
-crm status | grep "^Online:.*$NODE"
+crm status | grep "Online:.*$NODE"
 
 #
 # standby
@@ -32,11 +32,11 @@ crm status | grep "^Online:.*$NODE"
 
 crm node standby $NODE
 sleep $CRM_TIMEOUT
-crm status | grep "^Node $NODE: standby"
+crm status | grep "Node $NODE: standby"
 
 crm node online $NODE
 sleep $CRM_TIMEOUT
-crm status | grep "^Online:.*$NODE"
+crm status | grep "Online:.*$NODE"
 
 #
 # maintenance
@@ -44,11 +44,11 @@ crm status | grep "^Online:.*$NODE"
 
 crm node maintenance $NODE
 sleep $CRM_TIMEOUT
-crm status | grep "^Node $NODE: maintenance"
+crm status | grep "Node $NODE: maintenance"
 
 crm node ready $NODE
 sleep $CRM_TIMEOUT
-crm status | grep "^Online:.*$NODE"
+crm status | grep "Online:.*$NODE"
 
 #
 # attributes
